==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebAccordionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebAccordionDescription } from "./WebAccordionDescription";
/**
 * @hidden
 */
export let WebAccordionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebAccordionDescriptionMetadata extends Base {
        static b(a) {
            if (WebAccordionDescriptionMetadata.a == null) {
                WebAccordionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebAccordionDescriptionMetadata.c(WebAccordionDescriptionMetadata.a);
            }
            if (a.k(WebAccordionDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebAccordionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Accordion");
            a.item("__tagNameWC", "String:igc-accordion");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("SingleExpand", "Boolean");
        }
        static d(a) {
            WebAccordionDescriptionMetadata.b(a);
            a.ad("WebAccordion", () => new WebAccordionDescription());
            a.ac("WebAccordion", WebAccordionDescriptionMetadata.a);
        }
    }
    WebAccordionDescriptionMetadata.$t = markType(WebAccordionDescriptionMetadata, 'WebAccordionDescriptionMetadata');
    WebAccordionDescriptionMetadata.a = null;
    return WebAccordionDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebAccordionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExpansionPanelComponentEventArgsDescriptionMetadata } from "./WebExpansionPanelComponentEventArgsDescriptionMetadata";
import { WebAccordionDescription } from "./WebAccordionDescription";
/**
 * @hidden
 */
export let WebAccordionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebAccordionDescriptionMetadata extends Base {
        static b(a) {
            if (WebAccordionDescriptionMetadata.a == null) {
                WebAccordionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebAccordionDescriptionMetadata.c(WebAccordionDescriptionMetadata.a);
            }
            if (a.k(WebAccordionDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebAccordionDescriptionMetadata.a);
            WebExpansionPanelComponentEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Accordion");
            a.item("__tagNameWC", "String:igc-accordion");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("SingleExpand", "Boolean");
            a.item("OpeningRef", "EventRef::opening");
            a.item("OpenedRef", "EventRef::opened");
            a.item("ClosingRef", "EventRef::closing");
            a.item("ClosedRef", "EventRef::closed");
        }
        static d(a) {
            WebAccordionDescriptionMetadata.b(a);
            a.ae("WebAccordion", () => new WebAccordionDescription());
            a.ad("WebAccordion", WebAccordionDescriptionMetadata.a);
        }
    }
    WebAccordionDescriptionMetadata.$t = markType(WebAccordionDescriptionMetadata, 'WebAccordionDescriptionMetadata');
    WebAccordionDescriptionMetadata.a = null;
    return WebAccordionDescriptionMetadata;
})();
